% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sigDifProp.R
\name{sigrepDiv}
\alias{sigrepDiv}
\title{Significance of the difference in proportions with 95\% confidence interval (CI) for IMGT clonotype (AA) diversity between two sets from IMGT/HighV-QUEST output}
\source{
Gentleman R.C., Carey V.J., Bates D.M., Bolstad B., Dettling M., Dudoit S., et al. (2004) Bioconductor: Open software development for computational biology and bioinformatics R. Genome Biology, Vol. 5, R80, \url{https://www.bioconductor.org/}
}
\usage{
sigrepDiv(Data, data1, data2)
}
\arguments{
\item{Data}{the matrix issued from the function \code{\link{clonNumDiv}} containing the number of IMGT clonotypes (AA)}

\item{data1}{the first set from IMGT/HighV-QUEST output without CDR3-IMGT outlier lengths issued from the function \code{\link{clonRem}}}

\item{data2}{the second set from IMGT/HighV-QUEST output without CDR3-IMGT outlier lengths issued from the function \code{\link{clonRem}}}
}
\value{
A matrix of 21 columns:
 \item{Gene_Name}{
 The list of IMGT gene names found in the two compared sets from the IMGT/HighV-QUEST output
 }
 \item{Gene_Type}{
 The type of genes (V, D or J)
 }
 \item{Nb_IMGT_clonotype_AA.set1}{
 The nb of IMGT clonotypes (AA) in the first IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
  \item{Proportion.set1}{
 The proportion of IMGT clonotypes (AA) in the first IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{Normalized_proportion.set1}{
 The normalized proportion for 10000 IMGT clonotypes (AA) in the first IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{Nb_IMGT_clonotype_AA.set2}{
 The nb of IMGT clonotypes (AA) in the second IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{Proportion.set2}{
 The proportion of IMGT clonotypes (AA) in the second IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{Normalized_proportion.set2}{
 The normalized proportion for 10000 IMGT clonotypes (AA) in the second IMGT/HighV-QUEST output (set) with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{Difference_proportion}{
 The difference in proportions of IMGT clonotypes (AA) in the two compared sets from the IMGT/HighV-QUEST output with the corresponding gene indicated in the first column "Gene_Name"
 }
 \item{z}{
 The \emph{z}-score values to determine the significance of the difference between two proportions
 }
 \item{Lower_bound_IC_diff_prop}{
 The lower bound of the 95\% confidence interval (CI) for the difference in proportions of IMGT clonotypes (AA) in the two compared sets from the IMGT/HighV-QUEST output
 }
 \item{Upper_bound_IC_diff_prop}{
 The upper bound of the 95\% confidence interval (CI) for the difference in proportions of IMGT clonotypes (AA) in the two compared sets from the IMGT/HighV-QUEST output
 }
 \item{rawp}{
 The \emph{p}-values obtained from z-scores to evaluate the significance of difference in proportions of IMGT clonotypes (AA) in the two compared sets from the IMGT/HighV-QUEST output
 }
 \item{Bonferroni}{
 The adjusted \emph{p}-values issued from the Bonferroni multiple testing procedure
 }
 \item{Holm}{
 The adjusted \emph{p}-values issued from the Holm multiple testing procedure
 }
 \item{Hochberg}{
 The adjusted \emph{p}-values issued from the Hochberg multiple testing procedure
 }
 \item{SidakSS}{
 The adjusted \emph{p}-values issued from the Sidak single-step (SS) multiple testing procedure
 }
 \item{SidakSD}{
 The adjusted \emph{p}-values issued from the Sidak single-down (SD) multiple testing procedure
 }
 \item{BH}{
 The adjusted \emph{p}-values issued from the Benjamini & Hochberg (BH) multiple testing procedure
 }
 \item{BY}{
 The adjusted \emph{p}-values issued from the Benjamini & Yekutieli (BY) multiple testing procedure
 }
 \item{Test_interpretation}{
 The test interpretation: before adjustment of \emph{p}-values (rawp) non-significant and after adjustment by the multiple testing procedure: significant differences in proportions validated by the seven procedures (All_p), by two or more procedures (Min_2p) and only by BH (Only_BH)
 }
}
\description{
This function tests the significance of the difference in proportions with 95\% confidence interval (CI) for IMGT clonotype (AA) diversity.
}
\examples{
\donttest{
 div<-sigrepDiv(Ndiv,MID1,MID2)
}
}
\references{
Pollard K.S., Dudoit S., van der Laan M.J. (2005). Multiple testing procedures: R multtest package and applications to genomics. \emph{In}: Bioinformatics and Computational Biology Solutions Using R and Bioconductor. Gentleman R., Carey V.J., Huber W., Irizarry R.A., Dudoit S. (Eds) Springer (Statistics for Biology and Health Series), pp. 251-272.
}

